The branch, master, has been updated.

- Log -----------------------------------------------------------------

commit 75483b612c47e992c0fbf33b5181903d65c1a8e3
Author: Kornel Benko <[email protected]>
Date:   Wed Jan 9 13:45:58 2013 +0100

    Rename misleading function name from_gmtime() to form_asctime_utc()

diff --git a/src/support/lyxtime.cpp b/src/support/lyxtime.cpp
index f5290a2..3150825 100644
--- a/src/support/lyxtime.cpp
+++ b/src/support/lyxtime.cpp
@@ -40,7 +40,7 @@ string const formatted_time(time_t t, string const & fmt)
 }
 
 
-time_t from_gmtime(string t)
+time_t from_asctime_utc(string t)
 {
        // Example for the format: "Sun Nov  6 10:39:39 2011\n"
        // Generously remove trailing '\n' (and other whitespace if needed)
diff --git a/src/support/lyxtime.h b/src/support/lyxtime.h
index fcb22bd..74586cf 100644
--- a/src/support/lyxtime.h
+++ b/src/support/lyxtime.h
@@ -29,12 +29,9 @@ time_t current_time();
 std::string const formatted_time(time_t t, std::string const & fmt);
 
 /**
- * Inverse of ctime().
- * Since ctime() outputs the local time, the caller needs to ensure that the
- * time zone and daylight saving time are the same as when \p t was created
- * by ctime().
+ * Inverse of asctime(gmtime()).
  */
-time_t from_gmtime(std::string t);
+time_t from_asctime_utc(std::string t);
 
 } // namespace support
 } // namespace lyx
diff --git a/src/tex2lyx/text.cpp b/src/tex2lyx/text.cpp
index 2ccc7cd..ae44d85 100644
--- a/src/tex2lyx/text.cpp
+++ b/src/tex2lyx/text.cpp
@@ -3204,9 +3204,9 @@ void parse_text(Parser & p, ostream & os, unsigned flags, 
bool outer,
                        string localtime = p.getArg('{', '}');
                        preamble.registerAuthor(name);
                        Author const & author = preamble.getAuthor(name);
                        // from_gmtime() will fail if LyX decides to output the
output the
                        // time in the text language.
-                       time_t ptime = from_gmtime(localtime);
+                       time_t ptime = from_asctime_utc(localtime);
                        if (ptime == static_cast<time_t>(-1)) {
                                cerr << "Warning: Could not parse time `" << 
localtime
                                     << "´ for change tracking, using current 
time instead.\n";

-----------------------------------------------------------------------

Summary of changes:
 src/support/lyxtime.cpp |    2 +-
@@ -3204,9 +3204,9 @@ void parse_text(Parser & p, ostream & os, unsigned flags, 
                        preamble.registerAuthor(name);
                        Author const & author = preamble.getAuthor(name);
-                       // from_gmtime() will fail if LyX decides to output the
+                       // from_asctime_utc() will fail if LyX decides to 
output the
                        // time in the text language.
 src/support/lyxtime.h   |    7 ++-----
 src/tex2lyx/text.cpp    |    4 ++--
 3 files changed, 5 insertions(+), 8 deletions(-)


hooks/post-receive
-- 
The LyX Source Repository

Reply via email to